#[repr(u32)]pub enum AVStereo3DType {
AV_STEREO3D_2D = 0,
AV_STEREO3D_SIDEBYSIDE = 1,
AV_STEREO3D_TOPBOTTOM = 2,
AV_STEREO3D_FRAMESEQUENCE = 3,
AV_STEREO3D_CHECKERBOARD = 4,
AV_STEREO3D_SIDEBYSIDE_QUINCUNX = 5,
AV_STEREO3D_LINES = 6,
AV_STEREO3D_COLUMNS = 7,
}Expand description
List of possible 3D Types
Variants
AV_STEREO3D_2D = 0
Video is not stereoscopic (and metadata has to be there).
AV_STEREO3D_SIDEBYSIDE = 1
Views are next to each other.
@code{.unparsed} LLLLRRRR LLLLRRRR LLLLRRRR … @endcode
AV_STEREO3D_TOPBOTTOM = 2
Views are on top of each other.
@code{.unparsed} LLLLLLLL LLLLLLLL RRRRRRRR RRRRRRRR @endcode
AV_STEREO3D_FRAMESEQUENCE = 3
Views are alternated temporally.
@code{.unparsed} frame0 frame1 frame2 … LLLLLLLL RRRRRRRR LLLLLLLL LLLLLLLL RRRRRRRR LLLLLLLL LLLLLLLL RRRRRRRR LLLLLLLL … … … @endcode
AV_STEREO3D_CHECKERBOARD = 4
Views are packed in a checkerboard-like structure per pixel.
@code{.unparsed} LRLRLRLR RLRLRLRL LRLRLRLR … @endcode
AV_STEREO3D_SIDEBYSIDE_QUINCUNX = 5
Views are next to each other, but when upscaling apply a checkerboard pattern.
@code{.unparsed} LLLLRRRR L L L L R R R R LLLLRRRR => L L L L R R R R LLLLRRRR L L L L R R R R LLLLRRRR L L L L R R R R @endcode
AV_STEREO3D_LINES = 6
Views are packed per line, as if interlaced.
@code{.unparsed} LLLLLLLL RRRRRRRR LLLLLLLL … @endcode
AV_STEREO3D_COLUMNS = 7
Views are packed per column.
@code{.unparsed} LRLRLRLR LRLRLRLR LRLRLRLR … @endcode