#[repr(u32)]pub enum AVSubtitleType {
SUBTITLE_NONE = 0,
SUBTITLE_BITMAP = 1,
SUBTITLE_TEXT = 2,
SUBTITLE_ASS = 3,
}Expand description
@}
Variants
SUBTITLE_NONE = 0
SUBTITLE_BITMAP = 1
< A bitmap, pict will be set
SUBTITLE_TEXT = 2
Plain text, the text field must be set by the decoder and is authoritative. ass and pict fields may contain approximations.
SUBTITLE_ASS = 3
Formatted text, the ass field must be set by the decoder and is authoritative. pict and text fields may contain approximations.