Function ffmpeg_sys_next::av_asprintf
source · [−]Expand description
Print arguments following specified format into a large enough auto allocated buffer. It is similar to GNU asprintf(). @param fmt printf-compatible format string, specifying how the following parameters are used. @return the allocated string @note You have to free the string yourself with av_free().