Function ffmpeg_sys_next::av_hash_alloc
source · [−]Expand description
Allocate a hash context for the algorithm specified by name.
@return >= 0 for success, a negative error code for failure
@note The context is not initialized after a call to this function; you must call av_hash_init() to do so.