Function ffmpeg_sys_next::av_hmac_init
source · [−]Expand description
Initialize an AVHMAC context with an authentication key. @param ctx The HMAC context @param key The authentication key @param keylen The length of the key, in bytes
Initialize an AVHMAC context with an authentication key. @param ctx The HMAC context @param key The authentication key @param keylen The length of the key, in bytes