Function ffmpeg_sys_next::av_init_packet
source · [−]Expand description
Initialize optional fields of a packet with default values.
Note, this does not touch the data and size members, which have to be initialized separately.
@param pkt packet