Function ffmpeg_sys_next::av_packet_unref
source · [−]Expand description
Wipe the packet.
Unreference the buffer referenced by the packet and reset the remaining packet fields to their default values.
@param pkt The packet to be unreferenced.