Function ffmpeg_sys_next::avcodec_find_decoder
source · [−]Expand description
Find a registered decoder with a matching codec ID.
@param id AVCodecID of the requested decoder @return A decoder if one was found, NULL otherwise.
Find a registered decoder with a matching codec ID.
@param id AVCodecID of the requested decoder @return A decoder if one was found, NULL otherwise.