Function ffmpeg_sys_next::avdevice_register_all
source · pub unsafe extern "C" fn avdevice_register_all()Expand description
Initialize libavdevice and register all the input and output devices.
pub unsafe extern "C" fn avdevice_register_all()Initialize libavdevice and register all the input and output devices.