sws_frame_setup

Function sws_frame_setup 

pub unsafe extern "C" fn sws_frame_setup(
    ctx: *mut SwsContext,
    dst: *const AVFrame,
    src: *const AVFrame,
) -> c_int
Like sws_scale_frame, but without actually scaling. It will instead merely initialize internal state that would be required to perform the operation, as well as returning the correct error code for unsupported frame combinations.

@param ctx The scaling context. @param dst The destination frame to consider. @param src The source frame to consider. @return 0 on success, a negative AVERROR code on failure.