pub unsafe extern "C" fn sws_free_context(ctx: *mut *mut SwsContext)Expand description
Free the context and everything associated with it, and write NULL to the provided pointer.
pub unsafe extern "C" fn sws_free_context(ctx: *mut *mut SwsContext)Free the context and everything associated with it, and write NULL to the provided pointer.