Struct ffmpeg_sys_next::AVComponentDescriptor
source · [−]#[repr(C)]pub struct AVComponentDescriptor {
pub plane: c_int,
pub step: c_int,
pub offset: c_int,
pub shift: c_int,
pub depth: c_int,
pub step_minus1: c_int,
pub depth_minus1: c_int,
pub offset_plus1: c_int,
}Fields
plane: c_intWhich of the 4 planes contains the component.
step: c_intNumber of elements between 2 horizontally consecutive pixels. Elements are bits for bitstream formats, bytes otherwise.
offset: c_intNumber of elements before the component of the first pixel. Elements are bits for bitstream formats, bytes otherwise.
shift: c_intNumber of least significant bits that must be shifted away to get the value.
depth: c_intNumber of bits in the component.
step_minus1: c_intdeprecated, use step instead
depth_minus1: c_intdeprecated, use depth instead
offset_plus1: c_intdeprecated, use offset instead