#[repr(C)]pub struct AVDownmixInfo {
pub preferred_downmix_type: AVDownmixType,
pub center_mix_level: f64,
pub center_mix_level_ltrt: f64,
pub surround_mix_level: f64,
pub surround_mix_level_ltrt: f64,
pub lfe_mix_level: f64,
}Expand description
This structure describes optional metadata relevant to a downmix procedure.
All fields are set by the decoder to the value indicated in the audio bitstream (if present), or to a “sane” default otherwise.
Fields
preferred_downmix_type: AVDownmixTypeType of downmix preferred by the mastering engineer.
center_mix_level: f64Absolute scale factor representing the nominal level of the center channel during a regular downmix.
center_mix_level_ltrt: f64Absolute scale factor representing the nominal level of the center channel during an Lt/Rt compatible downmix.
surround_mix_level: f64Absolute scale factor representing the nominal level of the surround channels during a regular downmix.
surround_mix_level_ltrt: f64Absolute scale factor representing the nominal level of the surround channels during an Lt/Rt compatible downmix.
lfe_mix_level: f64Absolute scale factor representing the level at which the LFE data is mixed into L/R channels during downmixing.