Struct ffmpeg_sys_next::AVLFG
source · [−]Expand description
Context structure for the Lagged Fibonacci PRNG. The exact layout, types and content of this struct may change and should not be accessed directly. Only its sizeof() is guranteed to stay the same to allow easy instanciation.
Fields
state: [c_uint; 64]index: c_intTrait Implementations
impl Copy for AVLFG
impl Eq for AVLFG
impl StructuralEq for AVLFG
impl StructuralPartialEq for AVLFG